==> bigdata-common-0.0.53-sources.jar: cn/com/duiba/bigdata/common/biz/utils/HttpClientUtil.java <==
package cn.com.duiba.bigdata.common.biz.utils;

import lombok.extern.slf4j.Slf4j;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;

/**
 * @author xugf 2020-04-21
 * http连接工具类，短连接
 */
@Slf4j
public class HttpClientUtil {

    /**
     * 获取http返回的结果数据
     * @param url http 连接地址
     * @param body post请求时的body体
     * @param timeout 超时时间
     * @return http请求结果数据
     */
    public static String getHttpResponse(String url, StringEntity body, int timeout) {
        CloseableHttpClient httpClient = null;
        CloseableHttpResponse response = null;
        try {
            //实例化httpClient
            httpClient = HttpClients.createDefault();

            //构建http请求
            HttpUriRequest httpUriRequest = getHttpUriRequest(url, body, timeout);

            //执行请求
            response = httpClient.execute(httpUriRequest);
            return EntityUtils.toString(response.getEntity(), "UTF-8");
        } catch (Exception e) {
            log.error("getHttpResponse error,", e);
        } finally {
            try {
                if(response != null){
                    response.close();
                }
                if(httpClient != null){
                    httpClient.close();
                }
            } catch (Exception e2) {
                log.error("httpClient close error,", e2);
            }
        }

        return null;
    }

    //构建http请求
    private static HttpUriRequest getHttpUriRequest(String url, StringEntity body, int timeout) {
        if (body == null) {
            //http get请求
            return httpGet(url, timeout);
        } else {
            //http post请求
            return httpPost(url, body, timeout);
        }
    }

    //构建httpGet请求
    private static HttpGet httpGet(String url, int timeout) {
        HttpGet httpGet = new HttpGet(url);
        httpGet.setHeader("Content-Type", "application/json;charset=UTF-8");
        httpGet.setConfig(getRequestConfig(timeout));
        return httpGet;
    }

    //构建httpPost请求
    private static HttpPost httpPost(String url, StringEntity entity, int timeout) {
        HttpPost httpPost = new HttpPost(url);
        httpPost.setHeader("Content-Type", "application/json;charset=UTF-8");
        httpPost.setEntity(entity);
        httpPost.setConfig(getRequestConfig(timeout));
        return httpPost;
    }

    //http请求配置信息
    private static RequestConfig getRequestConfig(int timeout) {
        return RequestConfig.custom()
                .setRedirectsEnabled(false)
                .setSocketTimeout(timeout)
                .setConnectTimeout(timeout)
                .setConnectionRequestTimeout(timeout)
                .build();
    }
}

==> bigdata-common-0.0.73-sources.jar: cn/com/duiba/bigdata/common/biz/utils/HttpClientUtil.java <==
package cn.com.duiba.bigdata.common.biz.utils;

import lombok.extern.slf4j.Slf4j;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;

/**
 * @author xugf 2020-04-21
 * http连接工具类，短连接
 */
@Slf4j
public class HttpClientUtil {

    /**
     * 获取http返回的结果数据
     *
     * @param url     http 连接地址
     * @param body    post请求时的body体
     * @param timeout 超时时间
     * @return http请求结果数据
     */
    public static String getHttpResponse(String url, StringEntity body, int timeout) {
        try (CloseableHttpClient httpClient = HttpClients.createDefault()) {

            //构建http请求
            HttpUriRequest httpUriRequest = getHttpUriRequest(url, body, timeout);

            //执行请求
            CloseableHttpResponse response = httpClient.execute(httpUriRequest);

            return EntityUtils.toString(response.getEntity(), "UTF-8");
        } catch (Exception e) {
            log.error("getHttpResponse error,", e);
        }

        return null;
    }

    //构建http请求
    private static HttpUriRequest getHttpUriRequest(String url, StringEntity body, int timeout) {
        if (body == null) {
            //http get请求
            return httpGet(url, timeout);
        } else {
            //http post请求
            return httpPost(url, body, timeout);
        }
    }

    //构建httpGet请求
    private static HttpGet httpGet(String url, int timeout) {
        HttpGet httpGet = new HttpGet(url);
        httpGet.setHeader("Content-Type", "application/json;charset=UTF-8");
        httpGet.setConfig(getRequestConfig(timeout));
        return httpGet;
    }

    //构建httpPost请求
    private static HttpPost httpPost(String url, StringEntity entity, int timeout) {
        HttpPost httpPost = new HttpPost(url);
        httpPost.setHeader("Content-Type", "application/json;charset=UTF-8");
        httpPost.setEntity(entity);
        httpPost.setConfig(getRequestConfig(timeout));
        return httpPost;
    }

    //http请求配置信息
    private static RequestConfig getRequestConfig(int timeout) {
        return RequestConfig.custom()
                .setSocketTimeout(timeout)
                .setConnectTimeout(timeout)
                .setConnectionRequestTimeout(timeout)
                .build();
    }
}
